/*******************************************************************************
  * Copyright 2025 Intel Corporation
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *******************************************************************************/

  #define ippcpGetLibVersion l9_ippcpGetLibVersion
#define cryptoGetLibVersion l9_cryptoGetLibVersion
#define ippsDESGetSize l9_ippsDESGetSize
#define ippsDESInit l9_ippsDESInit
#define ippsDESPack l9_ippsDESPack
#define ippsDESUnpack l9_ippsDESUnpack
#define ippsTDESEncryptECB l9_ippsTDESEncryptECB
#define ippsTDESDecryptECB l9_ippsTDESDecryptECB
#define ippsTDESEncryptCBC l9_ippsTDESEncryptCBC
#define ippsTDESDecryptCBC l9_ippsTDESDecryptCBC
#define ippsTDESEncryptCFB l9_ippsTDESEncryptCFB
#define ippsTDESDecryptCFB l9_ippsTDESDecryptCFB
#define ippsTDESEncryptOFB l9_ippsTDESEncryptOFB
#define ippsTDESDecryptOFB l9_ippsTDESDecryptOFB
#define ippsTDESEncryptCTR l9_ippsTDESEncryptCTR
#define ippsTDESDecryptCTR l9_ippsTDESDecryptCTR
#define ippsAESGetSize l9_ippsAESGetSize
#define ippsAESInit l9_ippsAESInit
#define ippsAESSetKey l9_ippsAESSetKey
#define ippsAESPack l9_ippsAESPack
#define ippsAESUnpack l9_ippsAESUnpack
#define ippsAESEncryptECB l9_ippsAESEncryptECB
#define ippsAESDecryptECB l9_ippsAESDecryptECB
#define ippsAESEncryptCBC l9_ippsAESEncryptCBC
#define ippsAESEncryptCBC_CS1 l9_ippsAESEncryptCBC_CS1
#define ippsAESEncryptCBC_CS2 l9_ippsAESEncryptCBC_CS2
#define ippsAESEncryptCBC_CS3 l9_ippsAESEncryptCBC_CS3
#define ippsAESDecryptCBC l9_ippsAESDecryptCBC
#define ippsAESDecryptCBC_CS1 l9_ippsAESDecryptCBC_CS1
#define ippsAESDecryptCBC_CS2 l9_ippsAESDecryptCBC_CS2
#define ippsAESDecryptCBC_CS3 l9_ippsAESDecryptCBC_CS3
#define ippsAESEncryptCFB l9_ippsAESEncryptCFB
#define ippsAESDecryptCFB l9_ippsAESDecryptCFB
#define ippsAESEncryptOFB l9_ippsAESEncryptOFB
#define ippsAESDecryptOFB l9_ippsAESDecryptOFB
#define ippsAESEncryptCTR l9_ippsAESEncryptCTR
#define ippsAESDecryptCTR l9_ippsAESDecryptCTR
#define ippsAESEncryptXTS_Direct l9_ippsAESEncryptXTS_Direct
#define ippsAESDecryptXTS_Direct l9_ippsAESDecryptXTS_Direct
#define ippsAESSetupNoise l9_ippsAESSetupNoise
#define ippsAES_GCMSetupNoise l9_ippsAES_GCMSetupNoise
#define ippsAES_CMACSetupNoise l9_ippsAES_CMACSetupNoise
#define ippsAES_EncryptCFB16_MB l9_ippsAES_EncryptCFB16_MB
#define ippsSMS4GetSize l9_ippsSMS4GetSize
#define ippsSMS4Init l9_ippsSMS4Init
#define ippsSMS4SetKey l9_ippsSMS4SetKey
#define ippsSMS4EncryptECB l9_ippsSMS4EncryptECB
#define ippsSMS4DecryptECB l9_ippsSMS4DecryptECB
#define ippsSMS4EncryptCBC l9_ippsSMS4EncryptCBC
#define ippsSMS4EncryptCBC_CS1 l9_ippsSMS4EncryptCBC_CS1
#define ippsSMS4EncryptCBC_CS2 l9_ippsSMS4EncryptCBC_CS2
#define ippsSMS4EncryptCBC_CS3 l9_ippsSMS4EncryptCBC_CS3
#define ippsSMS4DecryptCBC l9_ippsSMS4DecryptCBC
#define ippsSMS4DecryptCBC_CS1 l9_ippsSMS4DecryptCBC_CS1
#define ippsSMS4DecryptCBC_CS2 l9_ippsSMS4DecryptCBC_CS2
#define ippsSMS4DecryptCBC_CS3 l9_ippsSMS4DecryptCBC_CS3
#define ippsSMS4EncryptCFB l9_ippsSMS4EncryptCFB
#define ippsSMS4DecryptCFB l9_ippsSMS4DecryptCFB
#define ippsSMS4EncryptOFB l9_ippsSMS4EncryptOFB
#define ippsSMS4DecryptOFB l9_ippsSMS4DecryptOFB
#define ippsSMS4EncryptCTR l9_ippsSMS4EncryptCTR
#define ippsSMS4DecryptCTR l9_ippsSMS4DecryptCTR
#define ippsSMS4_CCMGetSize l9_ippsSMS4_CCMGetSize
#define ippsSMS4_CCMInit l9_ippsSMS4_CCMInit
#define ippsSMS4_CCMMessageLen l9_ippsSMS4_CCMMessageLen
#define ippsSMS4_CCMTagLen l9_ippsSMS4_CCMTagLen
#define ippsSMS4_CCMStart l9_ippsSMS4_CCMStart
#define ippsSMS4_CCMEncrypt l9_ippsSMS4_CCMEncrypt
#define ippsSMS4_CCMDecrypt l9_ippsSMS4_CCMDecrypt
#define ippsSMS4_CCMGetTag l9_ippsSMS4_CCMGetTag
#define ippsAES_CCMGetSize l9_ippsAES_CCMGetSize
#define ippsAES_CCMInit l9_ippsAES_CCMInit
#define ippsAES_CCMMessageLen l9_ippsAES_CCMMessageLen
#define ippsAES_CCMTagLen l9_ippsAES_CCMTagLen
#define ippsAES_CCMStart l9_ippsAES_CCMStart
#define ippsAES_CCMEncrypt l9_ippsAES_CCMEncrypt
#define ippsAES_CCMDecrypt l9_ippsAES_CCMDecrypt
#define ippsAES_CCMGetTag l9_ippsAES_CCMGetTag
#define ippsAES_GCMGetSize l9_ippsAES_GCMGetSize
#define ippsAES_GCMInit l9_ippsAES_GCMInit
#define ippsAES_GCMReinit l9_ippsAES_GCMReinit
#define ippsAES_GCMReset l9_ippsAES_GCMReset
#define ippsAES_GCMProcessIV l9_ippsAES_GCMProcessIV
#define ippsAES_GCMProcessAAD l9_ippsAES_GCMProcessAAD
#define ippsAES_GCMStart l9_ippsAES_GCMStart
#define ippsAES_GCMEncrypt l9_ippsAES_GCMEncrypt
#define ippsAES_GCMDecrypt l9_ippsAES_GCMDecrypt
#define ippsAES_GCMGetTag l9_ippsAES_GCMGetTag
#define ippsAES_XTSGetSize l9_ippsAES_XTSGetSize
#define ippsAES_XTSInit l9_ippsAES_XTSInit
#define ippsAES_XTSEncrypt l9_ippsAES_XTSEncrypt
#define ippsAES_XTSDecrypt l9_ippsAES_XTSDecrypt
#define ippsAES_S2V_CMAC l9_ippsAES_S2V_CMAC
#define ippsAES_SIVEncrypt l9_ippsAES_SIVEncrypt
#define ippsAES_SIVDecrypt l9_ippsAES_SIVDecrypt
#define ippsAES_CMACGetSize l9_ippsAES_CMACGetSize
#define ippsAES_CMACInit l9_ippsAES_CMACInit
#define ippsAES_CMACUpdate l9_ippsAES_CMACUpdate
#define ippsAES_CMACFinal l9_ippsAES_CMACFinal
#define ippsAES_CMACGetTag l9_ippsAES_CMACGetTag
#define ippsARCFourCheckKey l9_ippsARCFourCheckKey
#define ippsARCFourGetSize l9_ippsARCFourGetSize
#define ippsARCFourInit l9_ippsARCFourInit
#define ippsARCFourReset l9_ippsARCFourReset
#define ippsARCFourPack l9_ippsARCFourPack
#define ippsARCFourUnpack l9_ippsARCFourUnpack
#define ippsARCFourEncrypt l9_ippsARCFourEncrypt
#define ippsARCFourDecrypt l9_ippsARCFourDecrypt
#define ippsHashGetSize l9_ippsHashGetSize
#define ippsHashInit l9_ippsHashInit
#define ippsHashPack l9_ippsHashPack
#define ippsHashUnpack l9_ippsHashUnpack
#define ippsHashDuplicate l9_ippsHashDuplicate
#define ippsHashUpdate l9_ippsHashUpdate
#define ippsHashGetTag l9_ippsHashGetTag
#define ippsHashFinal l9_ippsHashFinal
#define ippsHashMessage l9_ippsHashMessage
#define ippsHashMethod_MD5 l9_ippsHashMethod_MD5
#define ippsHashMethod_SM3 l9_ippsHashMethod_SM3
#define ippsHashMethod_SM3_NI l9_ippsHashMethod_SM3_NI
#define ippsHashMethod_SM3_TT l9_ippsHashMethod_SM3_TT
#define ippsHashMethod_SHA1 l9_ippsHashMethod_SHA1
#define ippsHashMethod_SHA1_NI l9_ippsHashMethod_SHA1_NI
#define ippsHashMethod_SHA1_TT l9_ippsHashMethod_SHA1_TT
#define ippsHashMethod_SHA256 l9_ippsHashMethod_SHA256
#define ippsHashMethod_SHA256_NI l9_ippsHashMethod_SHA256_NI
#define ippsHashMethod_SHA256_TT l9_ippsHashMethod_SHA256_TT
#define ippsHashMethod_SHA224 l9_ippsHashMethod_SHA224
#define ippsHashMethod_SHA224_NI l9_ippsHashMethod_SHA224_NI
#define ippsHashMethod_SHA224_TT l9_ippsHashMethod_SHA224_TT
#define ippsHashMethod_SHA512 l9_ippsHashMethod_SHA512
#define ippsHashMethod_SHA512_NI l9_ippsHashMethod_SHA512_NI
#define ippsHashMethod_SHA512_TT l9_ippsHashMethod_SHA512_TT
#define ippsHashMethod_SHA384 l9_ippsHashMethod_SHA384
#define ippsHashMethod_SHA384_NI l9_ippsHashMethod_SHA384_NI
#define ippsHashMethod_SHA384_TT l9_ippsHashMethod_SHA384_TT
#define ippsHashMethod_SHA512_256 l9_ippsHashMethod_SHA512_256
#define ippsHashMethod_SHA512_256_NI l9_ippsHashMethod_SHA512_256_NI
#define ippsHashMethod_SHA512_256_TT l9_ippsHashMethod_SHA512_256_TT
#define ippsHashMethod_SHA512_224 l9_ippsHashMethod_SHA512_224
#define ippsHashMethod_SHA512_224_NI l9_ippsHashMethod_SHA512_224_NI
#define ippsHashMethod_SHA512_224_TT l9_ippsHashMethod_SHA512_224_TT
#define ippsHashMethod_SHA3_224 l9_ippsHashMethod_SHA3_224
#define ippsHashMethod_SHA3_256 l9_ippsHashMethod_SHA3_256
#define ippsHashMethod_SHA3_384 l9_ippsHashMethod_SHA3_384
#define ippsHashMethod_SHA3_512 l9_ippsHashMethod_SHA3_512
#define ippsHashMethod_SHAKE128 l9_ippsHashMethod_SHAKE128
#define ippsHashMethod_SHAKE256 l9_ippsHashMethod_SHAKE256
#define ippsHashMethodGetSize l9_ippsHashMethodGetSize
#define ippsHashMethodSet_MD5 l9_ippsHashMethodSet_MD5
#define ippsHashMethodSet_SM3 l9_ippsHashMethodSet_SM3
#define ippsHashMethodSet_SM3_NI l9_ippsHashMethodSet_SM3_NI
#define ippsHashMethodSet_SM3_TT l9_ippsHashMethodSet_SM3_TT
#define ippsHashMethodSet_SHA1 l9_ippsHashMethodSet_SHA1
#define ippsHashMethodSet_SHA1_NI l9_ippsHashMethodSet_SHA1_NI
#define ippsHashMethodSet_SHA1_TT l9_ippsHashMethodSet_SHA1_TT
#define ippsHashMethodSet_SHA224 l9_ippsHashMethodSet_SHA224
#define ippsHashMethodSet_SHA224_NI l9_ippsHashMethodSet_SHA224_NI
#define ippsHashMethodSet_SHA224_TT l9_ippsHashMethodSet_SHA224_TT
#define ippsHashMethodSet_SHA256 l9_ippsHashMethodSet_SHA256
#define ippsHashMethodSet_SHA256_NI l9_ippsHashMethodSet_SHA256_NI
#define ippsHashMethodSet_SHA256_TT l9_ippsHashMethodSet_SHA256_TT
#define ippsHashMethodSet_SHA384 l9_ippsHashMethodSet_SHA384
#define ippsHashMethodSet_SHA384_NI l9_ippsHashMethodSet_SHA384_NI
#define ippsHashMethodSet_SHA384_TT l9_ippsHashMethodSet_SHA384_TT
#define ippsHashMethodSet_SHA512 l9_ippsHashMethodSet_SHA512
#define ippsHashMethodSet_SHA512_NI l9_ippsHashMethodSet_SHA512_NI
#define ippsHashMethodSet_SHA512_TT l9_ippsHashMethodSet_SHA512_TT
#define ippsHashMethodSet_SHA512_224 l9_ippsHashMethodSet_SHA512_224
#define ippsHashMethodSet_SHA512_224_NI l9_ippsHashMethodSet_SHA512_224_NI
#define ippsHashMethodSet_SHA512_224_TT l9_ippsHashMethodSet_SHA512_224_TT
#define ippsHashMethodSet_SHA512_256 l9_ippsHashMethodSet_SHA512_256
#define ippsHashMethodSet_SHA512_256_NI l9_ippsHashMethodSet_SHA512_256_NI
#define ippsHashMethodSet_SHA512_256_TT l9_ippsHashMethodSet_SHA512_256_TT
#define ippsHashMethodSet_SHA3_224 l9_ippsHashMethodSet_SHA3_224
#define ippsHashMethodSet_SHA3_256 l9_ippsHashMethodSet_SHA3_256
#define ippsHashMethodSet_SHA3_384 l9_ippsHashMethodSet_SHA3_384
#define ippsHashMethodSet_SHA3_512 l9_ippsHashMethodSet_SHA3_512
#define ippsHashMethodSet_SHAKE128 l9_ippsHashMethodSet_SHAKE128
#define ippsHashMethodSet_SHAKE256 l9_ippsHashMethodSet_SHAKE256
#define ippsHashStateMethodSet_SM3 l9_ippsHashStateMethodSet_SM3
#define ippsHashStateMethodSet_SM3_NI l9_ippsHashStateMethodSet_SM3_NI
#define ippsHashStateMethodSet_SM3_TT l9_ippsHashStateMethodSet_SM3_TT
#define ippsHashStateMethodSet_SHA256 l9_ippsHashStateMethodSet_SHA256
#define ippsHashStateMethodSet_SHA256_NI l9_ippsHashStateMethodSet_SHA256_NI
#define ippsHashStateMethodSet_SHA256_TT l9_ippsHashStateMethodSet_SHA256_TT
#define ippsHashStateMethodSet_SHA224 l9_ippsHashStateMethodSet_SHA224
#define ippsHashStateMethodSet_SHA224_NI l9_ippsHashStateMethodSet_SHA224_NI
#define ippsHashStateMethodSet_SHA224_TT l9_ippsHashStateMethodSet_SHA224_TT
#define ippsHashStateMethodSet_SHA512 l9_ippsHashStateMethodSet_SHA512
#define ippsHashStateMethodSet_SHA512_NI l9_ippsHashStateMethodSet_SHA512_NI
#define ippsHashStateMethodSet_SHA512_TT l9_ippsHashStateMethodSet_SHA512_TT
#define ippsHashStateMethodSet_SHA384 l9_ippsHashStateMethodSet_SHA384
#define ippsHashStateMethodSet_SHA384_NI l9_ippsHashStateMethodSet_SHA384_NI
#define ippsHashStateMethodSet_SHA384_TT l9_ippsHashStateMethodSet_SHA384_TT
#define ippsHashStateMethodSet_SHA512_256 l9_ippsHashStateMethodSet_SHA512_256
#define ippsHashStateMethodSet_SHA512_256_NI l9_ippsHashStateMethodSet_SHA512_256_NI
#define ippsHashStateMethodSet_SHA512_256_TT l9_ippsHashStateMethodSet_SHA512_256_TT
#define ippsHashStateMethodSet_SHA512_224 l9_ippsHashStateMethodSet_SHA512_224
#define ippsHashStateMethodSet_SHA512_224_NI l9_ippsHashStateMethodSet_SHA512_224_NI
#define ippsHashStateMethodSet_SHA512_224_TT l9_ippsHashStateMethodSet_SHA512_224_TT
#define ippsHashStateMethodSet_SHA3_224 l9_ippsHashStateMethodSet_SHA3_224
#define ippsHashStateMethodSet_SHA3_256 l9_ippsHashStateMethodSet_SHA3_256
#define ippsHashStateMethodSet_SHA3_384 l9_ippsHashStateMethodSet_SHA3_384
#define ippsHashStateMethodSet_SHA3_512 l9_ippsHashStateMethodSet_SHA3_512
#define ippsHashStateMethodSet_SHAKE128 l9_ippsHashStateMethodSet_SHAKE128
#define ippsHashStateMethodSet_SHAKE256 l9_ippsHashStateMethodSet_SHAKE256
#define ippsHashGetSize_rmf l9_ippsHashGetSize_rmf
#define ippsHashGetSizeOptimal_rmf l9_ippsHashGetSizeOptimal_rmf
#define ippsHashInit_rmf l9_ippsHashInit_rmf
#define ippsHashPack_rmf l9_ippsHashPack_rmf
#define ippsHashUnpack_rmf l9_ippsHashUnpack_rmf
#define ippsHashDuplicate_rmf l9_ippsHashDuplicate_rmf
#define ippsHashUpdate_rmf l9_ippsHashUpdate_rmf
#define ippsHashGetTag_rmf l9_ippsHashGetTag_rmf
#define ippsHashFinal_rmf l9_ippsHashFinal_rmf
#define ippsHashMessage_rmf l9_ippsHashMessage_rmf
#define ippsHashMethodGetInfo l9_ippsHashMethodGetInfo
#define ippsHashGetInfo_rmf l9_ippsHashGetInfo_rmf
#define ippsHashSqueeze_rmf l9_ippsHashSqueeze_rmf
#define ippsMGF l9_ippsMGF
#define ippsMGF1_rmf l9_ippsMGF1_rmf
#define ippsMGF2_rmf l9_ippsMGF2_rmf
#define ippsHMAC_GetSize l9_ippsHMAC_GetSize
#define ippsHMAC_Init l9_ippsHMAC_Init
#define ippsHMAC_Pack l9_ippsHMAC_Pack
#define ippsHMAC_Unpack l9_ippsHMAC_Unpack
#define ippsHMAC_Duplicate l9_ippsHMAC_Duplicate
#define ippsHMAC_Update l9_ippsHMAC_Update
#define ippsHMAC_Final l9_ippsHMAC_Final
#define ippsHMAC_GetTag l9_ippsHMAC_GetTag
#define ippsHMAC_Message l9_ippsHMAC_Message
#define ippsHMACGetSize_rmf l9_ippsHMACGetSize_rmf
#define ippsHMACInit_rmf l9_ippsHMACInit_rmf
#define ippsHMACPack_rmf l9_ippsHMACPack_rmf
#define ippsHMACUnpack_rmf l9_ippsHMACUnpack_rmf
#define ippsHMACDuplicate_rmf l9_ippsHMACDuplicate_rmf
#define ippsHMACUpdate_rmf l9_ippsHMACUpdate_rmf
#define ippsHMACFinal_rmf l9_ippsHMACFinal_rmf
#define ippsHMACGetTag_rmf l9_ippsHMACGetTag_rmf
#define ippsHMACMessage_rmf l9_ippsHMACMessage_rmf
#define ippsHKDF l9_ippsHKDF
#define ippsHKDF_extract l9_ippsHKDF_extract
#define ippsHKDF_expand l9_ippsHKDF_expand
#define ippsBigNumGetSize l9_ippsBigNumGetSize
#define ippsBigNumInit l9_ippsBigNumInit
#define ippsCmpZero_BN l9_ippsCmpZero_BN
#define ippsCmp_BN l9_ippsCmp_BN
#define ippsGetSize_BN l9_ippsGetSize_BN
#define ippsSet_BN l9_ippsSet_BN
#define ippsGet_BN l9_ippsGet_BN
#define ippsRef_BN l9_ippsRef_BN
#define ippsExtGet_BN l9_ippsExtGet_BN
#define ippsAdd_BN l9_ippsAdd_BN
#define ippsSub_BN l9_ippsSub_BN
#define ippsMul_BN l9_ippsMul_BN
#define ippsMAC_BN_I l9_ippsMAC_BN_I
#define ippsDiv_BN l9_ippsDiv_BN
#define ippsMod_BN l9_ippsMod_BN
#define ippsGcd_BN l9_ippsGcd_BN
#define ippsModInv_BN l9_ippsModInv_BN
#define ippsSetOctString_BN l9_ippsSetOctString_BN
#define ippsGetOctString_BN l9_ippsGetOctString_BN
#define ippsMontGetSize l9_ippsMontGetSize
#define ippsMontInit l9_ippsMontInit
#define ippsMontSet l9_ippsMontSet
#define ippsMontGet l9_ippsMontGet
#define ippsMontForm l9_ippsMontForm
#define ippsMontMul l9_ippsMontMul
#define ippsMontExp l9_ippsMontExp
#define ippsPRNGGetSize l9_ippsPRNGGetSize
#define ippsPRNGInit l9_ippsPRNGInit
#define ippsPRNGSetModulus l9_ippsPRNGSetModulus
#define ippsPRNGSetH0 l9_ippsPRNGSetH0
#define ippsPRNGSetAugment l9_ippsPRNGSetAugment
#define ippsPRNGSetSeed l9_ippsPRNGSetSeed
#define ippsPRNGGetSeed l9_ippsPRNGGetSeed
#define ippsPRNGen l9_ippsPRNGen
#define ippsPRNGen_BN l9_ippsPRNGen_BN
#define ippsPRNGenRDRAND l9_ippsPRNGenRDRAND
#define ippsPRNGenRDRAND_BN l9_ippsPRNGenRDRAND_BN
#define ippsTRNGenRDSEED l9_ippsTRNGenRDSEED
#define ippsTRNGenRDSEED_BN l9_ippsTRNGenRDSEED_BN
#define ippsPrimeGetSize l9_ippsPrimeGetSize
#define ippsPrimeInit l9_ippsPrimeInit
#define ippsPrimeGen l9_ippsPrimeGen
#define ippsPrimeTest l9_ippsPrimeTest
#define ippsPrimeGen_BN l9_ippsPrimeGen_BN
#define ippsPrimeTest_BN l9_ippsPrimeTest_BN
#define ippsPrimeGet l9_ippsPrimeGet
#define ippsPrimeGet_BN l9_ippsPrimeGet_BN
#define ippsPrimeSet l9_ippsPrimeSet
#define ippsPrimeSet_BN l9_ippsPrimeSet_BN
#define ippsRSA_GetSizePublicKey l9_ippsRSA_GetSizePublicKey
#define ippsRSA_InitPublicKey l9_ippsRSA_InitPublicKey
#define ippsRSA_SetPublicKey l9_ippsRSA_SetPublicKey
#define ippsRSA_GetPublicKey l9_ippsRSA_GetPublicKey
#define ippsRSA_GetSizePrivateKeyType1 l9_ippsRSA_GetSizePrivateKeyType1
#define ippsRSA_InitPrivateKeyType1 l9_ippsRSA_InitPrivateKeyType1
#define ippsRSA_SetPrivateKeyType1 l9_ippsRSA_SetPrivateKeyType1
#define ippsRSA_GetPrivateKeyType1 l9_ippsRSA_GetPrivateKeyType1
#define ippsRSA_GetSizePrivateKeyType2 l9_ippsRSA_GetSizePrivateKeyType2
#define ippsRSA_InitPrivateKeyType2 l9_ippsRSA_InitPrivateKeyType2
#define ippsRSA_SetPrivateKeyType2 l9_ippsRSA_SetPrivateKeyType2
#define ippsRSA_GetPrivateKeyType2 l9_ippsRSA_GetPrivateKeyType2
#define ippsRSA_GetBufferSizePublicKey l9_ippsRSA_GetBufferSizePublicKey
#define ippsRSA_GetBufferSizePrivateKey l9_ippsRSA_GetBufferSizePrivateKey
#define ippsRSA_Encrypt l9_ippsRSA_Encrypt
#define ippsRSA_Decrypt l9_ippsRSA_Decrypt
#define ippsRSA_GenerateKeys l9_ippsRSA_GenerateKeys
#define ippsRSA_ValidateKeys l9_ippsRSA_ValidateKeys
#define ippsRSAEncrypt_OAEP l9_ippsRSAEncrypt_OAEP
#define ippsRSADecrypt_OAEP l9_ippsRSADecrypt_OAEP
#define ippsRSAEncrypt_OAEP_rmf l9_ippsRSAEncrypt_OAEP_rmf
#define ippsRSADecrypt_OAEP_rmf l9_ippsRSADecrypt_OAEP_rmf
#define ippsRSAEncrypt_PKCSv15 l9_ippsRSAEncrypt_PKCSv15
#define ippsRSADecrypt_PKCSv15 l9_ippsRSADecrypt_PKCSv15
#define ippsRSASign_PSS l9_ippsRSASign_PSS
#define ippsRSAVerify_PSS l9_ippsRSAVerify_PSS
#define ippsRSASign_PSS_rmf l9_ippsRSASign_PSS_rmf
#define ippsRSAVerify_PSS_rmf l9_ippsRSAVerify_PSS_rmf
#define ippsRSASign_PKCS1v15 l9_ippsRSASign_PKCS1v15
#define ippsRSAVerify_PKCS1v15 l9_ippsRSAVerify_PKCS1v15
#define ippsRSASign_PKCS1v15_rmf l9_ippsRSASign_PKCS1v15_rmf
#define ippsRSAVerify_PKCS1v15_rmf l9_ippsRSAVerify_PKCS1v15_rmf
#define ippsDLGetResultString l9_ippsDLGetResultString
#define ippsDLPGetSize l9_ippsDLPGetSize
#define ippsDLPInit l9_ippsDLPInit
#define ippsDLPPack l9_ippsDLPPack
#define ippsDLPUnpack l9_ippsDLPUnpack
#define ippsDLPSet l9_ippsDLPSet
#define ippsDLPGet l9_ippsDLPGet
#define ippsDLPSetDP l9_ippsDLPSetDP
#define ippsDLPGetDP l9_ippsDLPGetDP
#define ippsDLPGenKeyPair l9_ippsDLPGenKeyPair
#define ippsDLPPublicKey l9_ippsDLPPublicKey
#define ippsDLPValidateKeyPair l9_ippsDLPValidateKeyPair
#define ippsDLPSetKeyPair l9_ippsDLPSetKeyPair
#define ippsDLPSignDSA l9_ippsDLPSignDSA
#define ippsDLPVerifyDSA l9_ippsDLPVerifyDSA
#define ippsDLPSharedSecretDH l9_ippsDLPSharedSecretDH
#define ippsDLPGenerateDSA l9_ippsDLPGenerateDSA
#define ippsDLPValidateDSA l9_ippsDLPValidateDSA
#define ippsDLPGenerateDH l9_ippsDLPGenerateDH
#define ippsDLPValidateDH l9_ippsDLPValidateDH
#define ippsECCGetResultString l9_ippsECCGetResultString
#define ippsGFpGetSize l9_ippsGFpGetSize
#define ippsGFpInitArbitrary l9_ippsGFpInitArbitrary
#define ippsGFpInitFixed l9_ippsGFpInitFixed
#define ippsGFpInit l9_ippsGFpInit
#define ippsGFpMethod_p192r1 l9_ippsGFpMethod_p192r1
#define ippsGFpMethod_p224r1 l9_ippsGFpMethod_p224r1
#define ippsGFpMethod_p256r1 l9_ippsGFpMethod_p256r1
#define ippsGFpMethod_p384r1 l9_ippsGFpMethod_p384r1
#define ippsGFpMethod_p521r1 l9_ippsGFpMethod_p521r1
#define ippsGFpMethod_p256sm2 l9_ippsGFpMethod_p256sm2
#define ippsGFpMethod_p256bn l9_ippsGFpMethod_p256bn
#define ippsGFpMethod_p256 l9_ippsGFpMethod_p256
#define ippsGFpMethod_pArb l9_ippsGFpMethod_pArb
#define ippsGFpxGetSize l9_ippsGFpxGetSize
#define ippsGFpxInit l9_ippsGFpxInit
#define ippsGFpxInitBinomial l9_ippsGFpxInitBinomial
#define ippsGFpxMethod_binom2_epid2 l9_ippsGFpxMethod_binom2_epid2
#define ippsGFpxMethod_binom3_epid2 l9_ippsGFpxMethod_binom3_epid2
#define ippsGFpxMethod_binom2 l9_ippsGFpxMethod_binom2
#define ippsGFpxMethod_binom3 l9_ippsGFpxMethod_binom3
#define ippsGFpxMethod_binom l9_ippsGFpxMethod_binom
#define ippsGFpxMethod_com l9_ippsGFpxMethod_com
#define ippsGFpScratchBufferSize l9_ippsGFpScratchBufferSize
#define ippsGFpElementGetSize l9_ippsGFpElementGetSize
#define ippsGFpElementInit l9_ippsGFpElementInit
#define ippsGFpSetElement l9_ippsGFpSetElement
#define ippsGFpSetElementRegular l9_ippsGFpSetElementRegular
#define ippsGFpSetElementOctString l9_ippsGFpSetElementOctString
#define ippsGFpSetElementRandom l9_ippsGFpSetElementRandom
#define ippsGFpSetElementHash l9_ippsGFpSetElementHash
#define ippsGFpSetElementHash_rmf l9_ippsGFpSetElementHash_rmf
#define ippsGFpCpyElement l9_ippsGFpCpyElement
#define ippsGFpGetElement l9_ippsGFpGetElement
#define ippsGFpGetElementOctString l9_ippsGFpGetElementOctString
#define ippsGFpCmpElement l9_ippsGFpCmpElement
#define ippsGFpIsZeroElement l9_ippsGFpIsZeroElement
#define ippsGFpIsUnityElement l9_ippsGFpIsUnityElement
#define ippsGFpConj l9_ippsGFpConj
#define ippsGFpNeg l9_ippsGFpNeg
#define ippsGFpInv l9_ippsGFpInv
#define ippsGFpSqrt l9_ippsGFpSqrt
#define ippsGFpSqr l9_ippsGFpSqr
#define ippsGFpAdd l9_ippsGFpAdd
#define ippsGFpSub l9_ippsGFpSub
#define ippsGFpMul l9_ippsGFpMul
#define ippsGFpExp l9_ippsGFpExp
#define ippsGFpMultiExp l9_ippsGFpMultiExp
#define ippsGFpAdd_PE l9_ippsGFpAdd_PE
#define ippsGFpSub_PE l9_ippsGFpSub_PE
#define ippsGFpMul_PE l9_ippsGFpMul_PE
#define ippsGFpGetInfo l9_ippsGFpGetInfo
#define ippsGFpECGetSize l9_ippsGFpECGetSize
#define ippsGFpECInit l9_ippsGFpECInit
#define ippsGFpECSet l9_ippsGFpECSet
#define ippsGFpECSetSubgroup l9_ippsGFpECSetSubgroup
#define ippsGFpECInitStd128r1 l9_ippsGFpECInitStd128r1
#define ippsGFpECInitStd128r2 l9_ippsGFpECInitStd128r2
#define ippsGFpECInitStd192r1 l9_ippsGFpECInitStd192r1
#define ippsGFpECInitStd224r1 l9_ippsGFpECInitStd224r1
#define ippsGFpECInitStd256r1 l9_ippsGFpECInitStd256r1
#define ippsGFpECInitStd384r1 l9_ippsGFpECInitStd384r1
#define ippsGFpECInitStd521r1 l9_ippsGFpECInitStd521r1
#define ippsGFpECInitStdSM2 l9_ippsGFpECInitStdSM2
#define ippsGFpECInitStdBN256 l9_ippsGFpECInitStdBN256
#define ippsGFpECBindGxyTblStd192r1 l9_ippsGFpECBindGxyTblStd192r1
#define ippsGFpECBindGxyTblStd224r1 l9_ippsGFpECBindGxyTblStd224r1
#define ippsGFpECBindGxyTblStd256r1 l9_ippsGFpECBindGxyTblStd256r1
#define ippsGFpECBindGxyTblStd384r1 l9_ippsGFpECBindGxyTblStd384r1
#define ippsGFpECBindGxyTblStd521r1 l9_ippsGFpECBindGxyTblStd521r1
#define ippsGFpECBindGxyTblStdSM2 l9_ippsGFpECBindGxyTblStdSM2
#define ippsGFpECGet l9_ippsGFpECGet
#define ippsGFpECGetSubgroup l9_ippsGFpECGetSubgroup
#define ippsGFpECScratchBufferSize l9_ippsGFpECScratchBufferSize
#define ippsGFpECVerify l9_ippsGFpECVerify
#define ippsGFpECPointGetSize l9_ippsGFpECPointGetSize
#define ippsGFpECPointInit l9_ippsGFpECPointInit
#define ippsGFpECSetPointAtInfinity l9_ippsGFpECSetPointAtInfinity
#define ippsGFpECSetPoint l9_ippsGFpECSetPoint
#define ippsGFpECSetPointRegular l9_ippsGFpECSetPointRegular
#define ippsGFpECSetPointRandom l9_ippsGFpECSetPointRandom
#define ippsGFpECMakePoint l9_ippsGFpECMakePoint
#define ippsGFpECSetPointHash l9_ippsGFpECSetPointHash
#define ippsGFpECSetPointHashBackCompatible l9_ippsGFpECSetPointHashBackCompatible
#define ippsGFpECSetPointHash_rmf l9_ippsGFpECSetPointHash_rmf
#define ippsGFpECSetPointHashBackCompatible_rmf l9_ippsGFpECSetPointHashBackCompatible_rmf
#define ippsGFpECGetPoint l9_ippsGFpECGetPoint
#define ippsGFpECGetPointRegular l9_ippsGFpECGetPointRegular
#define ippsGFpECSetPointOctString l9_ippsGFpECSetPointOctString
#define ippsGFpECGetPointOctString l9_ippsGFpECGetPointOctString
#define ippsGFpECTstPoint l9_ippsGFpECTstPoint
#define ippsGFpECTstPointInSubgroup l9_ippsGFpECTstPointInSubgroup
#define ippsGFpECCpyPoint l9_ippsGFpECCpyPoint
#define ippsGFpECCmpPoint l9_ippsGFpECCmpPoint
#define ippsGFpECNegPoint l9_ippsGFpECNegPoint
#define ippsGFpECAddPoint l9_ippsGFpECAddPoint
#define ippsGFpECMulPoint l9_ippsGFpECMulPoint
#define ippsGFpECPrivateKey l9_ippsGFpECPrivateKey
#define ippsGFpECPublicKey l9_ippsGFpECPublicKey
#define ippsGFpECTstKeyPair l9_ippsGFpECTstKeyPair
#define ippsGFpECSharedSecretDH l9_ippsGFpECSharedSecretDH
#define ippsGFpECSharedSecretDHC l9_ippsGFpECSharedSecretDHC
#define ippsGFpECMessageRepresentationSM2 l9_ippsGFpECMessageRepresentationSM2
#define ippsGFpECSignDSA l9_ippsGFpECSignDSA
#define ippsGFpECVerifyDSA l9_ippsGFpECVerifyDSA
#define ippsGFpECSignNR l9_ippsGFpECSignNR
#define ippsGFpECVerifyNR l9_ippsGFpECVerifyNR
#define ippsGFpECSignSM2 l9_ippsGFpECSignSM2
#define ippsGFpECVerifySM2 l9_ippsGFpECVerifySM2
#define ippsGFpECUserIDHashSM2 l9_ippsGFpECUserIDHashSM2
#define ippsGFpECKeyExchangeSM2_GetSize l9_ippsGFpECKeyExchangeSM2_GetSize
#define ippsGFpECKeyExchangeSM2_Init l9_ippsGFpECKeyExchangeSM2_Init
#define ippsGFpECKeyExchangeSM2_Setup l9_ippsGFpECKeyExchangeSM2_Setup
#define ippsGFpECKeyExchangeSM2_SharedKey l9_ippsGFpECKeyExchangeSM2_SharedKey
#define ippsGFpECKeyExchangeSM2_Confirm l9_ippsGFpECKeyExchangeSM2_Confirm
#define ippsGFpECGetInfo_GF l9_ippsGFpECGetInfo_GF
#define ippsGFpECESGetSize_SM2 l9_ippsGFpECESGetSize_SM2
#define ippsGFpECESInit_SM2 l9_ippsGFpECESInit_SM2
#define ippsGFpECESSetKey_SM2 l9_ippsGFpECESSetKey_SM2
#define ippsGFpECESStart_SM2 l9_ippsGFpECESStart_SM2
#define ippsGFpECESEncrypt_SM2 l9_ippsGFpECESEncrypt_SM2
#define ippsGFpECESDecrypt_SM2 l9_ippsGFpECESDecrypt_SM2
#define ippsGFpECESFinal_SM2 l9_ippsGFpECESFinal_SM2
#define ippsGFpECESGetBuffersSize_SM2 l9_ippsGFpECESGetBuffersSize_SM2
#define ippsGFpECEncryptSM2_Ext_EncMsgSize l9_ippsGFpECEncryptSM2_Ext_EncMsgSize
#define ippsGFpECEncryptSM2_Ext l9_ippsGFpECEncryptSM2_Ext
#define ippsGFpECDecryptSM2_Ext_DecMsgSize l9_ippsGFpECDecryptSM2_Ext_DecMsgSize
#define ippsGFpECDecryptSM2_Ext l9_ippsGFpECDecryptSM2_Ext
#define ippsXMSSBufferGetSize l9_ippsXMSSBufferGetSize
#define ippsXMSSVerifyBufferGetSize l9_ippsXMSSVerifyBufferGetSize
#define ippsXMSSKeyGenBufferGetSize l9_ippsXMSSKeyGenBufferGetSize
#define ippsXMSSSignBufferGetSize l9_ippsXMSSSignBufferGetSize
#define ippsXMSSPrivateKeyStateGetSize l9_ippsXMSSPrivateKeyStateGetSize
#define ippsXMSSPublicKeyStateGetSize l9_ippsXMSSPublicKeyStateGetSize
#define ippsXMSSSignatureStateGetSize l9_ippsXMSSSignatureStateGetSize
#define ippsXMSSInitSignature l9_ippsXMSSInitSignature
#define ippsXMSSInitKeyPair l9_ippsXMSSInitKeyPair
#define ippsXMSSSetPublicKeyState l9_ippsXMSSSetPublicKeyState
#define ippsXMSSSetSignatureState l9_ippsXMSSSetSignatureState
#define ippsXMSSKeyGen l9_ippsXMSSKeyGen
#define ippsXMSSSign l9_ippsXMSSSign
#define ippsXMSSVerify l9_ippsXMSSVerify
#define ippsLMSBufferGetSize l9_ippsLMSBufferGetSize
#define ippsLMSVerifyBufferGetSize l9_ippsLMSVerifyBufferGetSize
#define ippsLMSSignatureStateGetSize l9_ippsLMSSignatureStateGetSize
#define ippsLMSPublicKeyStateGetSize l9_ippsLMSPublicKeyStateGetSize
#define ippsLMSSetPublicKeyState l9_ippsLMSSetPublicKeyState
#define ippsLMSSetSignatureState l9_ippsLMSSetSignatureState
#define ippsLMSVerify l9_ippsLMSVerify
#define ippsMLKEM_GetSize l9_ippsMLKEM_GetSize
#define ippsMLKEM_GetInfo l9_ippsMLKEM_GetInfo
#define ippsMLKEM_Init l9_ippsMLKEM_Init
#define ippsMLKEM_KeyGenBufferGetSize l9_ippsMLKEM_KeyGenBufferGetSize
#define ippsMLKEM_EncapsBufferGetSize l9_ippsMLKEM_EncapsBufferGetSize
#define ippsMLKEM_DecapsBufferGetSize l9_ippsMLKEM_DecapsBufferGetSize
#define ippsMLKEM_KeyGen l9_ippsMLKEM_KeyGen
#define ippsMLKEM_Encaps l9_ippsMLKEM_Encaps
#define ippsMLKEM_Decaps l9_ippsMLKEM_Decaps
